Functions
- evaluate_
assertion - Evaluate an assertion expression.
Returns
Ok(Some(result))when the AST engine handled the expression,Ok(None)when the expression should fall through to the JQ evaluator.
Ok(Some(result)) when the AST engine handled the expression,
Ok(None) when the expression should fall through to the JQ evaluator.